@@ -13,12 +13,7 @@ TOLERANCE = 0.001
 TEST_REPEAT_COUNT = 100
 
 
-def get_float(calculator_output: str) -> float:
-    """Get float from Calculator output string."""
-    return float(calculator_output.split()[-1])
-
-
-def test_operations():
+def test_simple_operations():
     """Test add, subtract, multiply, divide operations
     with big and small numbers.
     """
@@ -31,18 +26,26 @@ def test_operations():
 
     for operation in operations_order:
         number = random.choice((small_numbers(), big_numbers()))
-        calculator_function = getattr(calculator, operation)
-        function_output = get_float(calculator_function(number))
+        calculator_method = getattr(calculator, operation)
+        method_output = calculator_method(number).answer()
         if operation == "add":
-            assert math.isclose(calculator_memory + number, function_output, abs_tol=TOLERANCE)
+            assert math.isclose(
+                calculator_memory + number, method_output, abs_tol=TOLERANCE
+            )
         elif operation == "subtract":
-            assert math.isclose(calculator_memory - number, function_output, abs_tol=TOLERANCE)
+            assert math.isclose(
+                calculator_memory - number, method_output, abs_tol=TOLERANCE
+            )
         elif operation == "multiply":
-            assert math.isclose(calculator_memory * number, function_output, abs_tol=TOLERANCE)
+            assert math.isclose(
+                calculator_memory * number, method_output, abs_tol=TOLERANCE
+            )
         elif operation == "divide":
-            assert math.isclose(calculator_memory / number, function_output, abs_tol=TOLERANCE)
+            assert math.isclose(
+                calculator_memory / number, method_output, abs_tol=TOLERANCE
+            )
 
-        calculator_memory = function_output
+        calculator_memory = method_output
 
 
 def test_root_and_reset():
@@ -59,8 +62,10 @@ def test_root_and_reset():
         calculator_memory = random.choice((small_numbers(), big_numbers()))
         degree = random.choice((small_numbers(), big_numbers()))
         calculator.reset(calculator_memory)
-        function_output = get_float(calculator.root(degree))
-        assert math.isclose(calculator_memory ** (1 / degree), function_output, abs_tol=TOLERANCE)
+        method_output = calculator.root(degree).answer()
+        assert math.isclose(
+            calculator_memory ** (1 / degree), method_output, abs_tol=TOLERANCE
+        )
 
 
 def test_operations_zero():
@@ -68,16 +73,16 @@ def test_operations_zero():
     ZERO = 0
 
     calculator = Calculator(ZERO)
-    calculator_output = get_float(str(calculator))
+    calculator_output = calculator.answer()
     assert calculator_output == ZERO
 
-    calculator_output = get_float(calculator.add(ZERO))
+    calculator_output = calculator.add(ZERO).answer()
     assert calculator_output == ZERO
 
-    calculator_output = get_float(calculator.subtract(ZERO))
+    calculator_output = calculator.subtract(ZERO).answer()
     assert calculator_output == ZERO
 
-    calculator_output = get_float(calculator.multiply(ZERO))
+    calculator_output = calculator.multiply(ZERO).answer()
     assert calculator_output == ZERO
 
     with pytest.raises(ZeroDivisionError):
